Installation
============

In order to install *pypop7*, it is **highly recommended** to use the Python3-based virtual environment via `venv <https://docs.python.org/3/library/venv.html>`_ or `conda <https://docs.conda.io/projects/conda/en/latest/index.html>`_:

Pip via Python Package Index (PyPI)
-----------------------------------

.. code-block:: bash

    pip install pypop7
